pub struct TlsConfig {
pub connector: TlsConnector,
pub hostnames: TlsHostMapping,
}Expand description
TLS configuration for a client.
Note: the hostnames field is only necessary to use with certain clustered deployments.
let config = TlsConfig {
// or use `TlsConnector::default_rustls()`
connector: TlsConnector::default_native_tls().unwrap(),
hostnames: TlsHostMapping::None
};
// or use the shorthand
let config: TlsConfig = TlsConnector::default_native_tls()?.into();
let config: TlsConfig = TlsConnector::default_rustls()?.into();Fields
connector: TlsConnectorThe TLS connector from either native-tls or rustls.
hostnames: TlsHostMappingThe hostname modification or mapping policy to use when discovering and connecting to cluster nodes.